@@ -1,5 +1,5 @@
 /*
- * $Id: conffile.h 275 2007-02-23 12:20:01Z jblache $
+ * $Id: conffile.h 295 2007-03-08 17:48:00Z jblache $
  */
 
 #ifndef __CONFFILE_H__
@@ -11,4 +11,10 @@ config_load(void);
 int
 config_write(void);
 
+int
+config_monitor(void);
+
+void
+config_gui(void);
+
 #endif /* !__CONFFILE_H__ */
