@@ -1,15 +1,30 @@
 /*
- * $Id: ambient.h 183 2006-12-24 11:16:30Z julien $
+ * $Id: ambient.h 339 2007-07-15 20:23:28Z jblache $
  */
 
 #ifndef __AMBIENT_H__
 #define __AMBIENT_H__
 
-
-#define KBD_AMBIENT_SENSOR      "/sys/devices/platform/applesmc/light"
 #define KBD_AMBIENT_MIN         0
 #define KBD_AMBIENT_MAX         255
 
+#ifdef __powerpc__
+/* I2C ioctl */
+# define I2C_SLAVE           0x0703
+
+# define ADB_DEVICE          "/dev/adb"
+# define ADB_BUFFER_SIZE     32
+
+struct _lmu_info
+{
+  unsigned int lmuaddr;  /* i2c bus address */
+  char i2cdev[16];       /* i2c bus device */
+};
+
+extern struct _lmu_info lmu_info;
+
+#endif /* !__powerpc__ */
+
 
 struct _ambient_info
 {
