@@ -1,7 +1,7 @@
 /*
  * pommed - Apple laptops hotkeys handler daemon
  *
- * $Id: conffile.c 345 2007-07-27 14:00:46Z jblache $
+ * $Id: conffile.c 387 2007-11-25 13:27:01Z jblache $
  *
  * Copyright (C) 2006-2007 Julien BLACHE <jb@jblache.org>
  *
@@ -32,6 +32,7 @@
 #include "lcd_backlight.h"
 #include "kbd_backlight.h"
 #include "cd_eject.h"
+#include "beep.h"
 #include "audio.h"
 
 
@@ -46,6 +47,7 @@ struct _lcd_nv8600mgt_cfg lcd_nv8600mgt_cfg;
 struct _audio_cfg audio_cfg;
 struct _kbd_cfg kbd_cfg;
 struct _eject_cfg eject_cfg;
+struct _beep_cfg beep_cfg;
 #ifndef __powerpc__
 struct _appleir_cfg appleir_cfg;
 #endif
@@ -67,17 +69,8 @@ static cfg_opt_t lcd_sysfs_opts[] =
     CFG_END()
   };
 
-static cfg_opt_t audio_opts[] =
-  {
-    CFG_STR("card", "default", CFGF_NONE),
-    CFG_INT("init", -1, CFGF_NONE),
-    CFG_INT("step", 10, CFGF_NONE),
-    CFG_STR("volume", "Master", CFGF_NONE),
-    CFG_STR("speakers", "Master", CFGF_NONE),
-    CFG_STR("headphones", "Headphone", CFGF_NONE),
-    CFG_END()
-  };
 #else
+
 static cfg_opt_t lcd_x1600_opts[] =
   {
     CFG_INT("init", -1, CFGF_NONE),
@@ -101,19 +94,20 @@ static cfg_opt_t lcd_nv8600mgt_opts[] =
     CFG_INT("on_batt", 0, CFGF_NONE),
     CFG_END()
   };
+#endif /* __powerpc__ */
+
 
 static cfg_opt_t audio_opts[] =
   {
     CFG_STR("card", "default", CFGF_NONE),
     CFG_INT("init", -1, CFGF_NONE),
     CFG_INT("step", 10, CFGF_NONE),
+    CFG_BOOL("beep", 1, CFGF_NONE),
     CFG_STR("volume", "PCM", CFGF_NONE),
     CFG_STR("speakers", "Front", CFGF_NONE),
     CFG_STR("headphones", "Headphone", CFGF_NONE),
     CFG_END()
   };
-#endif /* __powerpc__ */
-
 
 static cfg_opt_t kbd_opts[] =
   {
@@ -122,6 +116,7 @@ static cfg_opt_t kbd_opts[] =
     CFG_INT("on_threshold", 20, CFGF_NONE),
     CFG_INT("off_threshold", 40, CFGF_NONE),
     CFG_BOOL("auto", 1, CFGF_NONE),
+    CFG_INT("idle_timer", 60, CFGF_NONE),
     CFG_END()
   };
 
@@ -132,6 +127,13 @@ static cfg_opt_t eject_opts[] =
     CFG_END()
   };
 
+static cfg_opt_t beep_opts[] =
+  {
+    CFG_BOOL("enabled", 0, CFGF_NONE),
+    CFG_STR("beepfile", BEEP_DEFAULT_FILE, CFGF_NONE),
+    CFG_END()
+  };
+
 #ifndef __powerpc__
 static cfg_opt_t appleir_opts[] =
   {
@@ -153,6 +155,7 @@ static cfg_opt_t opts[] =
     CFG_SEC("audio", audio_opts, CFGF_NONE),
     CFG_SEC("kbd", kbd_opts, CFGF_NONE),
     CFG_SEC("eject", eject_opts, CFGF_NONE),
+    CFG_SEC("beep", beep_opts, CFGF_NONE),
 #ifndef __powerpc__
     CFG_SEC("appleir", appleir_opts, CFGF_NONE),
 #endif
@@ -218,6 +221,7 @@ config_print(void)
   printf("    card: %s\n", audio_cfg.card);
   printf("    initial volume: %d%s\n", audio_cfg.init, (audio_cfg.init > -1) ? "%" : "");
   printf("    step: %d%%\n", audio_cfg.step);
+  printf("    beep: %s\n", (audio_cfg.beep) ? "yes" : "no");
   printf("    volume element: %s\n", audio_cfg.vol);
   printf("    speaker element: %s\n", audio_cfg.spkr);
   printf("    headphones element: %s\n", audio_cfg.head);
@@ -227,9 +231,13 @@ config_print(void)
   printf("    auto on threshold: %d\n", kbd_cfg.on_thresh);
   printf("    auto off threshold: %d\n", kbd_cfg.off_thresh);
   printf("    auto enable: %s\n", (kbd_cfg.auto_on) ? "yes" : "no");
+  printf("    idle timer: %d%s\n", (kbd_cfg.idle * LOOP_TIMEOUT) / 1000, (kbd_cfg.idle > 0) ? "s" : "");
   printf(" + CD eject:\n");
   printf("    enabled: %s\n", (eject_cfg.enabled) ? "yes" : "no");
   printf("    device: %s\n", eject_cfg.device);
+  printf(" + Beep:\n");
+  printf("    enabled: %s\n", (beep_cfg.enabled) ? "yes" : "no");
+  printf("    beepfile: %s\n", beep_cfg.beepfile);
 #ifndef __powerpc__
   printf(" + Apple Remote IR Receiver:\n");
   printf("    enabled: %s\n", (appleir_cfg.enabled) ? "yes" : "no");
@@ -285,6 +293,8 @@ config_load(void)
   cfg_set_validate_func(cfg, "kbd|off_threshold", config_validate_positive_integer);
   /* CD eject */
   cfg_set_validate_func(cfg, "eject|device", config_validate_string);
+  /* beep */
+  cfg_set_validate_func(cfg, "beep|beepfile", config_validate_string);
 
   /* 
    * Do the actual parsing.
@@ -343,6 +353,7 @@ config_load(void)
   audio_cfg.card = strdup(cfg_getstr(sec, "card"));
   audio_cfg.init = cfg_getint(sec, "init");
   audio_cfg.step = cfg_getint(sec, "step");
+  audio_cfg.beep = cfg_getbool(sec, "beep");
   audio_cfg.vol = strdup(cfg_getstr(sec, "volume"));
   audio_cfg.spkr = strdup(cfg_getstr(sec, "speakers"));
   audio_cfg.head = strdup(cfg_getstr(sec, "headphones"));
@@ -354,6 +365,7 @@ config_load(void)
   kbd_cfg.on_thresh = cfg_getint(sec, "on_threshold");
   kbd_cfg.off_thresh = cfg_getint(sec, "off_threshold");
   kbd_cfg.auto_on = cfg_getbool(sec, "auto");
+  kbd_cfg.idle = cfg_getint(sec, "idle_timer");
   kbd_backlight_fix_config();
 
   sec = cfg_getsec(cfg, "eject");
@@ -361,6 +373,11 @@ config_load(void)
   eject_cfg.device = strdup(cfg_getstr(sec, "device"));
   cd_eject_fix_config();
 
+  sec = cfg_getsec(cfg, "beep");
+  beep_cfg.enabled = cfg_getbool(sec, "enabled");
+  beep_cfg.beepfile = strdup(cfg_getstr(sec, "beepfile"));
+  beep_fix_config();
+
 #ifndef __powerpc__
   sec = cfg_getsec(cfg, "appleir");
   appleir_cfg.enabled = cfg_getbool(sec, "enabled");
@@ -383,4 +400,6 @@ config_cleanup(void)
   free(audio_cfg.head);
 
   free(eject_cfg.device);
+
+  free(beep_cfg.beepfile);
 }
