@@ -1,5 +1,5 @@
 /*
- * $Id: conffile.h 345 2007-07-27 14:00:46Z jblache $
+ * $Id: conffile.h 387 2007-11-25 13:27:01Z jblache $
  */
 
 #ifndef __CONFFILE_H__
@@ -42,6 +42,7 @@ struct _audio_cfg {
   char *card;
   int init;
   int step;
+  int beep;
   char *vol;
   char *spkr;
   char *head;
@@ -53,6 +54,7 @@ struct _kbd_cfg {
   int on_thresh;
   int off_thresh;
   int auto_on;
+  int idle;
 };
 
 struct _eject_cfg {
@@ -60,6 +62,11 @@ struct _eject_cfg {
   char *device;
 };
 
+struct _beep_cfg {
+  int enabled;
+  char *beepfile;
+};
+
 #ifndef __powerpc__
 struct _appleir_cfg {
   int enabled;
@@ -78,6 +85,7 @@ extern struct _lcd_nv8600mgt_cfg lcd_nv8600mgt_cfg;
 extern struct _audio_cfg audio_cfg;
 extern struct _kbd_cfg kbd_cfg;
 extern struct _eject_cfg eject_cfg;
+extern struct _beep_cfg beep_cfg;
 #ifndef __powerpc__
 extern struct _appleir_cfg appleir_cfg;
 #endif
