@@ -1,7 +1,7 @@
 /*
  * pommed - Apple laptops hotkeys handler daemon
  *
- * $Id: dbus.c 341 2007-07-26 15:49:44Z jblache $
+ * $Id: dbus.c 388 2007-11-26 10:31:11Z jblache $
  *
  * Copyright (C) 2006-2007 Julien BLACHE <jb@jblache.org>
  *
@@ -332,6 +332,43 @@ mbpdbus_send_cd_eject(void)
   dbus_message_unref(msg);
 }
 
+void
+mbpdbus_send_video_switch(void)
+{
+  DBusMessage *msg;
+
+  int ret;
+
+  if (conn == NULL)
+    return;
+
+  logdebug("DBus video switch\n");
+
+  msg = dbus_message_new_signal("/org/pommed/notify/videoSwitch",
+				"org.pommed.signal.videoSwitch",
+				"videoSwitch");
+  if (msg == NULL)
+    {
+      logdebug("Failed to create DBus message\n");
+
+      return;
+    }
+
+  ret = dbus_connection_send(conn, msg, NULL);
+  if (ret == FALSE)
+    {
+      logdebug("Could not send videoSwitch signal\n");
+
+      dbus_message_unref(msg);
+
+      return;
+    }
+
+  dbus_connection_flush(conn);
+
+  dbus_message_unref(msg);
+}
+
 
 static void
 process_lcd_getlevel_call(DBusMessage *req)
