@@ -1,7 +1,7 @@
 /*
  * pommed - Apple laptops hotkeys handler daemon
  *
- * $Id: evdev.c 417 2007-12-07 12:39:59Z jblache $
+ * $Id: evdev.c 463 2008-05-18 10:05:06Z jblache $
  *
  * Copyright (C) 2006-2007 Julien BLACHE <jb@jblache.org>
  *
@@ -438,7 +438,7 @@ evdev_event_loop(void)
 
 #ifdef __powerpc__
 /* PowerBook G4 Titanium */
-int
+static int
 evdev_is_adb(unsigned short *id)
 {
   unsigned short product = id[ID_PRODUCT];
@@ -467,7 +467,7 @@ evdev_is_adb(unsigned short *id)
 }
 
 /* PowerBook G4 */
-int
+static int
 evdev_is_fountain(unsigned short *id)
 {
   unsigned short product = id[ID_PRODUCT];
@@ -482,7 +482,7 @@ evdev_is_fountain(unsigned short *id)
       || (product == USB_PRODUCT_ID_FOUNTAIN_ISO)
       || (product == USB_PRODUCT_ID_FOUNTAIN_JIS))
     {
-      logdebug(" -> Fountain USB keyboard\n");
+      logdebug(" -> Fountain USB assembly\n");
 
       return 1;
     }
@@ -490,7 +490,7 @@ evdev_is_fountain(unsigned short *id)
   return 0;
 }
 
-int
+static int
 evdev_is_geyser(unsigned short *id)
 {
   unsigned short product = id[ID_PRODUCT];
@@ -505,7 +505,7 @@ evdev_is_geyser(unsigned short *id)
       || (product == USB_PRODUCT_ID_GEYSER_ISO)
       || (product == USB_PRODUCT_ID_GEYSER_JIS))
     {
-      logdebug(" -> Geyser USB keyboard\n");
+      logdebug(" -> Geyser USB assembly\n");
 
       kbd_set_fnmode();
 
@@ -515,6 +515,16 @@ evdev_is_geyser(unsigned short *id)
   return 0;
 }
 
+/* Any internal keyboard */
+static int
+evdev_is_internal(unsigned short *id)
+{
+  return (evdev_is_adb(id)
+	  || evdev_is_fountain(id)
+	  || evdev_is_geyser(id));
+}
+
+
 /* PMU Lid switch */
 static int
 evdev_is_lidswitch(unsigned short *id)
@@ -543,7 +553,7 @@ evdev_is_lidswitch(unsigned short *id)
 #else
 
 /* Core Duo MacBook & MacBook Pro */
-int
+static int
 evdev_is_geyser3(unsigned short *id)
 {
   unsigned short product = id[ID_PRODUCT];
@@ -558,7 +568,7 @@ evdev_is_geyser3(unsigned short *id)
       || (product == USB_PRODUCT_ID_GEYSER3_ISO)
       || (product == USB_PRODUCT_ID_GEYSER3_JIS))
     {
-      logdebug(" -> Geyser III USB keyboard\n");
+      logdebug(" -> Geyser III USB assembly\n");
 
       kbd_set_fnmode();
 
@@ -569,7 +579,7 @@ evdev_is_geyser3(unsigned short *id)
 }
 
 /* Core2 Duo MacBook & MacBook Pro */
-int
+static int
 evdev_is_geyser4(unsigned short *id)
 {
   unsigned short product = id[ID_PRODUCT];
@@ -584,7 +594,7 @@ evdev_is_geyser4(unsigned short *id)
       || (product == USB_PRODUCT_ID_GEYSER4_ISO)
       || (product == USB_PRODUCT_ID_GEYSER4_JIS))
     {
-      logdebug(" -> Geyser IV USB keyboard\n");
+      logdebug(" -> Geyser IV USB assembly\n");
 
       kbd_set_fnmode();
 
@@ -594,8 +604,9 @@ evdev_is_geyser4(unsigned short *id)
   return 0;
 }
 
-/* Core2 Duo Santa Rosa MacBook (MacBook3,1) */
-int
+/* Core2 Duo Santa Rosa MacBook (MacBook3,1)
+   Core2 Duo MacBook (MacBook4,1, February 2008) */
+static int
 evdev_is_geyser4hf(unsigned short *id)
 {
   unsigned short product = id[ID_PRODUCT];
@@ -610,7 +621,7 @@ evdev_is_geyser4hf(unsigned short *id)
       || (product == USB_PRODUCT_ID_GEYSER4HF_ISO)
       || (product == USB_PRODUCT_ID_GEYSER4HF_JIS))
     {
-      logdebug(" -> Geyser IV-HF USB keyboard\n");
+      logdebug(" -> Geyser IV-HF USB assembly\n");
 
       kbd_set_fnmode();
 
@@ -620,6 +631,70 @@ evdev_is_geyser4hf(unsigned short *id)
   return 0;
 }
 
+/* MacBook Air (MacBookAir1,1, January 2008) */
+static int
+evdev_is_wellspring(unsigned short *id)
+{
+  unsigned short product = id[ID_PRODUCT];
+
+  if (id[ID_BUS] != BUS_USB)
+    return 0;
+
+  if (id[ID_VENDOR] != USB_VENDOR_ID_APPLE)
+    return 0;
+
+  if ((product == USB_PRODUCT_ID_WELLSPRING_ANSI)
+      || (product == USB_PRODUCT_ID_WELLSPRING_ISO)
+      || (product == USB_PRODUCT_ID_WELLSPRING_JIS))
+    {
+      logdebug(" -> WellSpring USB assembly\n");
+
+      kbd_set_fnmode();
+
+      return 1;
+    }
+
+  return 0;
+}
+
+/* Core2 Duo MacBook Pro (MacBookPro4,1, February 2008) */
+static int
+evdev_is_wellspring2(unsigned short *id)
+{
+  unsigned short product = id[ID_PRODUCT];
+
+  if (id[ID_BUS] != BUS_USB)
+    return 0;
+
+  if (id[ID_VENDOR] != USB_VENDOR_ID_APPLE)
+    return 0;
+
+  if ((product == USB_PRODUCT_ID_WELLSPRING2_ANSI)
+      || (product == USB_PRODUCT_ID_WELLSPRING2_ISO)
+      || (product == USB_PRODUCT_ID_WELLSPRING2_JIS))
+    {
+      logdebug(" -> WellSpring II USB assembly\n");
+
+      kbd_set_fnmode();
+
+      return 1;
+    }
+
+  return 0;
+}
+
+/* Any internal keyboard */
+static int
+evdev_is_internal(unsigned short *id)
+{
+  return (evdev_is_geyser3(id)
+	  || evdev_is_geyser4(id)
+	  || evdev_is_geyser4hf(id)
+	  || evdev_is_wellspring(id)
+	  || evdev_is_wellspring2(id));
+}
+
+
 /* Apple Remote IR Receiver */
 static int
 evdev_is_appleir(unsigned short *id)
@@ -666,9 +741,9 @@ evdev_is_lidswitch(unsigned short *id)
 }
 #endif /* !__powerpc__ */
 
-/* External Apple USB keyboards */
-int
-evdev_is_extkbd(unsigned short *id)
+/* Apple external USB keyboard, white */
+static int
+evdev_is_extkbd_white(unsigned short *id)
 {
   unsigned short product = id[ID_PRODUCT];
 
@@ -678,10 +753,9 @@ evdev_is_extkbd(unsigned short *id)
   if (id[ID_VENDOR] != USB_VENDOR_ID_APPLE)
     return 0;
 
-  if ((product == USB_PRODUCT_ID_APPLE_EXTKBD_WHITE)
-      || (product == USB_PRODUCT_ID_APPLE_EXTKBD_ALU))
+  if (product == USB_PRODUCT_ID_APPLE_EXTKBD_WHITE)
     {
-      logdebug(" -> External Apple USB keyboard\n");
+      logdebug(" -> External Apple USB keyboard (white)\n");
 
       kbd_set_fnmode();
 
@@ -691,6 +765,67 @@ evdev_is_extkbd(unsigned short *id)
   return 0;
 }
 
+/* Apple external USB keyboard, aluminium */
+static int
+evdev_is_extkbd_alu(unsigned short *id)
+{
+  unsigned short product = id[ID_PRODUCT];
+
+  if (id[ID_BUS] != BUS_USB)
+    return 0;
+
+  if (id[ID_VENDOR] != USB_VENDOR_ID_APPLE)
+    return 0;
+
+  if ((product == USB_PRODUCT_ID_APPLE_EXTKBD_ALU_ANSI)
+      || (product == USB_PRODUCT_ID_APPLE_EXTKBD_ALU_ISO)
+      || (product == USB_PRODUCT_ID_APPLE_EXTKBD_ALU_JIS))
+    {
+      logdebug(" -> External Apple USB keyboard (aluminium)\n");
+
+      kbd_set_fnmode();
+
+      return 1;
+    }
+
+  return 0;
+}
+
+/* Apple external wireless keyboard, aluminium */
+static int
+evdev_is_extkbd_alu_wl(unsigned short *id)
+{
+  unsigned short product = id[ID_PRODUCT];
+
+  if (id[ID_BUS] != BUS_USB)
+    return 0;
+
+  if (id[ID_VENDOR] != USB_VENDOR_ID_APPLE)
+    return 0;
+
+  if ((product == USB_PRODUCT_ID_APPLE_EXTKBD_ALU_WL_ANSI)
+      || (product == USB_PRODUCT_ID_APPLE_EXTKBD_ALU_WL_ISO)
+      || (product == USB_PRODUCT_ID_APPLE_EXTKBD_ALU_WL_JIS))
+    {
+      logdebug(" -> External Apple wireless keyboard (aluminium)\n");
+
+      kbd_set_fnmode();
+
+      return 1;
+    }
+
+  return 0;
+}
+
+/* Any external Apple USB keyboard */
+static int
+evdev_is_extkbd(unsigned short *id)
+{
+  return (evdev_is_extkbd_white(id)
+	  || evdev_is_extkbd_alu(id)
+	  || evdev_is_extkbd_alu_wl(id));
+}
+
 /* Mouseemu virtual keyboard */
 static int
 evdev_is_mouseemu(unsigned short *id)
@@ -730,7 +865,7 @@ evdev_try_add(int fd)
 
   ioctl(fd, EVIOCGID, id);
 
-  if ((!mops->evdev_identify(id))
+  if ((!evdev_is_internal(id))
 #ifndef __powerpc__
       && !(appleir_cfg.enabled && evdev_is_appleir(id))
 #endif
