@@ -1,5 +1,5 @@
 /*
- * $Id: kbd_backlight.h 432 2008-01-23 13:33:31Z jblache $
+ * $Id: kbd_backlight.h 452 2008-04-05 16:07:48Z jblache $
  */
 
 #ifndef __KBD_BACKLIGHT_H__
@@ -7,6 +7,7 @@
 
 #ifndef __powerpc__
 #define KBD_BACKLIGHT           "/sys/class/leds/smc:kbd_backlight/brightness"
+#define KBD_BACKLIGHT_2625      "/sys/class/leds/smc::kbd_backlight/brightness"
 #endif /* !__powerpc__ */
 
 
@@ -70,6 +71,7 @@ has_kbd_backlight(void)
   return ((mops->type == MACHINE_MACBOOKPRO_1)
 	  || (mops->type == MACHINE_MACBOOKPRO_2)
 	  || (mops->type == MACHINE_MACBOOKPRO_3)
+	  || (mops->type == MACHINE_MACBOOKPRO_4)
 	  || (mops->type == MACHINE_MACBOOKAIR_1));
 }
 #endif /* __powerpc__ */
