@@ -1,11 +1,11 @@
 /*
  * pommed - Apple laptops hotkeys handler daemon
  *
- * MacBook Backlight Control (Intel GMA950)
+ * MacBook Backlight Control (Intel GMA950 & GMA965)
  *
- * $Id: gma950_backlight.c 344 2007-07-27 13:52:53Z jblache $
+ * $Id: gma950_backlight.c 411 2007-12-01 21:47:06Z jblache $
  *
- * Copyright (C) 2006 Ryan Lortie <desrt@desrt.ca>
+ * Copyright (C) 2006-2007 Ryan Lortie <desrt@desrt.ca>
  * Copyright (C) 2006-2007 Julien BLACHE <jb@jblache.org>
  *  + Adapted for pommed
  *
@@ -23,30 +23,29 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  *
- * This program was written after I reverse engineered the
- * AppleIntelIntegratedFramebuffer.kext kernel extension in Mac OS X and
- * played with the register at the memory location I found therein.
+ * The GMA950 has a backlight control register at offset 0x00061254 in its
+ * PCI memory space (512K region):
+ *  - bits 0-15 represent the backlight value
+ *  - bits 16 indicates legacy mode is in use when set
+ *  - bits 17-31 hold the max backlight value << 1
  *
- * From my experiments, the register appears to have two halves.
+ * Bit 16 indicates whether the backlight control should be used in legacy
+ * mode or not. This bit is 0 on MacBooks, indicating native mode should be
+ * used. This is the only method supported here.
  *
- * yyyyyyyyyyyyyyy0xxxxxxxxxxxxxxx0
  *
- * The top (y) bits appear to be the maximum brightness level and the
- * bottom (x) bits are the current brightness level.  0s are always 0.
- * The brightness level is, therefore, x/y.
+ * The GMA965 is slightly different; the backlight control register is at
+ * offset 0x00061250 in its PCI memory space (first 512K in the 1M region):
+ *  - bits 0-15 represent the backlight value
+ *  - bits 16-31 hold the max backlight value
+ *  - bit 30 indicates legacy mode is in use when set
  *
- * As my Macbook boots, y is set to 0x94 and x is set to 0x1f.  Going below
- * 0x1f produces odd results.  For example, if you come from above, the
- * backlight will completely turn off at 0x12 (18).  Coming from below,
- * however, you need to get to 0x15 (21) before the backlight comes back on.
  *
- * Since there is no clear cut boundry, I assume that this value specifies
- * a raw voltage.  Also, it appears that the bootup value of 0x1f corresponds
- * to the lowest level that Mac OS X will set the backlight I choose this
- * value as a minimum.
+ * For BOTH cards, the register for the backlight value is at offset 0x00061254.
  *
- * For the maximum I do not let the value exceed the value in the upper 15
- * bits.
+ *
+ * For both cards, in the code below, max value and current value are expressed
+ * on 15 bits; the values are shifted as appropriate when appropriate.
  */
 
 #include <stdio.h>
@@ -73,15 +72,18 @@
 
 static unsigned int GMA950_BACKLIGHT_MAX;
 
-
 static int fd = -1;
 static char *memory = NULL;
 static long address = 0;
 static long length = 0;
 
+#define REGISTER_OFFSET           0x00061254
 
-#define REGISTER_OFFSET       0x00061254
+#define GMA950_LEGACY_MODE        (1 << 16)
+#define GMA950_CONTROL_REGISTER   0x00061254
 
+#define GMA965_LEGACY_MODE        (1 << 30)
+#define GMA965_CONTROL_REGISTER   0x00061250
 
 static inline unsigned int
 readl(const volatile void *addr)
@@ -281,14 +283,16 @@ gma950_backlight_fix_config(void)
 
 #define PCI_ID_VENDOR_INTEL      0x8086
 #define PCI_ID_PRODUCT_GMA950    0x27A2
+#define PCI_ID_PRODUCT_GMA965    0x2A02
 
-/* Look for an Intel GMA950 */
+/* Look for an Intel GMA950 or GMA965 */
 int
 gma950_backlight_probe(void)
 {
   struct pci_access *pacc;
   struct pci_dev *dev;
 
+  int card;
   int ret;
 
   pacc = pci_alloc();
@@ -301,14 +305,18 @@ gma950_backlight_probe(void)
   pci_init(pacc);
   pci_scan_bus(pacc);
 
+  card = 0;
   /* Iterate over all devices */
   for(dev = pacc->devices; dev; dev = dev->next)
     {
       pci_fill_info(dev, PCI_FILL_IDENT | PCI_FILL_BASES);
-      /* GMA950 */
+      /* GMA950 or GMA965 */
       if ((dev->vendor_id == PCI_ID_VENDOR_INTEL)
-	  && (dev->device_id == PCI_ID_PRODUCT_GMA950))
+	  && ((dev->device_id == PCI_ID_PRODUCT_GMA950)
+	      || (dev->device_id == PCI_ID_PRODUCT_GMA965)))
 	{
+	  card = dev->device_id;
+
 	  address = dev->base_addr[0];
 	  length = dev->size[0];
 
@@ -320,20 +328,43 @@ gma950_backlight_probe(void)
 
   if (!address)
     {
-      logdebug("Failed to detect Intel GMA950, aborting...\n");
+      logdebug("Failed to detect Intel GMA950 or GMA965, aborting...\n");
       return -1;
     }
 
-  /* Get the maximum backlight value */
   ret = gma950_backlight_map();
   if (ret < 0)
     {
-      logmsg(LOG_ERR, "Could not determine max backlight value");
+      logmsg(LOG_ERR, "Could not map GMA950/GMA965 memory");
       return -1;
     }
 
+  if (card == PCI_ID_PRODUCT_GMA950)
+    {
+      if (INREG(GMA950_CONTROL_REGISTER) & GMA950_LEGACY_MODE)
+	{
+	  logdebug("GMA950 is in legacy backlight control mode, unsupported\n");
+
+	  gma950_backlight_unmap();
+	  return -1;
+	}
+    }
+  else if (card == PCI_ID_PRODUCT_GMA965)
+    {
+      if (INREG(GMA965_CONTROL_REGISTER) & GMA965_LEGACY_MODE)
+	{
+	  logdebug("GMA965 is in legacy backlight control mode, unsupported\n");
+
+	  gma950_backlight_unmap();
+	  return -1;
+	}
+    }
+
+  /* Get the maximum backlight value */
   GMA950_BACKLIGHT_MAX = gma950_backlight_get_max();
 
+  logdebug("Max LCD backlight value is 0x%x\n", GMA950_BACKLIGHT_MAX);
+
   /* Now, check the config and fix it if needed */
   gma950_backlight_fix_config();
 
