@@ -1,7 +1,7 @@
 /*
  * pommed - Apple laptops hotkeys handler daemon
  *
- * $Id: kbd_backlight.c 330 2007-05-19 17:09:13Z jblache $
+ * $Id: kbd_backlight.c 352 2007-08-22 14:14:16Z jblache $
  *
  * Copyright (C) 2006-2007 Julien BLACHE <jb@jblache.org>
  * Copyright (C) 2006 Yves-Alexis Perez <corsac@corsac.net>
@@ -55,20 +55,6 @@ struct _lmu_info lmu_info;
 struct _kbd_bck_info kbd_bck_info;
 
 
-int
-has_kbd_backlight(void)
-{
-  return ((mops->type == MACHINE_POWERBOOK_51)
-	  || (mops->type == MACHINE_POWERBOOK_52)
-	  || (mops->type == MACHINE_POWERBOOK_53)
-	  || (mops->type == MACHINE_POWERBOOK_54)
-	  || (mops->type == MACHINE_POWERBOOK_55)
-	  || (mops->type == MACHINE_POWERBOOK_56)
-	  || (mops->type == MACHINE_POWERBOOK_57)
-	  || (mops->type == MACHINE_POWERBOOK_58)
-	  || (mops->type == MACHINE_POWERBOOK_59));
-}
-
 static int
 kbd_backlight_get(void)
 {
@@ -395,6 +381,9 @@ kbd_backlight_fix_config(void)
 
   if (kbd_cfg.step > (KBD_BACKLIGHT_MAX / 2))
     kbd_cfg.step = KBD_BACKLIGHT_MAX / 2;
+
+  if (kbd_cfg.idle > 0)
+    kbd_cfg.idle = (kbd_cfg.idle * 1000) / LOOP_TIMEOUT;
 }
 
 
