@@ -1,7 +1,7 @@
 /*
  * pommed - Apple laptops hotkeys handler daemon
  *
- * $Id: pommed.c 434 2008-02-08 20:36:15Z jblache $
+ * $Id: pommed.c 460 2008-05-18 09:56:51Z jblache $
  *
  * Copyright (C) 2006-2008 Julien BLACHE <jb@jblache.org>
  *
@@ -76,7 +76,7 @@ struct machine_ops pb_mops[] = {
     .lcd_backlight_probe = aty128_sysfs_backlight_probe,
     .lcd_backlight_step = sysfs_backlight_step_kernel,
     .lcd_backlight_toggle = sysfs_backlight_toggle_kernel,
-    .evdev_identify = evdev_is_adb,
+    /* .evdev_identify = evdev_is_adb, */
   },
 
   {  /* PowerBook3,3 */
@@ -84,7 +84,7 @@ struct machine_ops pb_mops[] = {
     .lcd_backlight_probe = r9x00_sysfs_backlight_probe,
     .lcd_backlight_step = sysfs_backlight_step,
     .lcd_backlight_toggle = sysfs_backlight_toggle,
-    .evdev_identify = evdev_is_adb,
+    /* .evdev_identify = evdev_is_adb, */
   },
 
   {  /* PowerBook3,4 */
@@ -92,7 +92,7 @@ struct machine_ops pb_mops[] = {
     .lcd_backlight_probe = r9x00_sysfs_backlight_probe,
     .lcd_backlight_step = sysfs_backlight_step,
     .lcd_backlight_toggle = sysfs_backlight_toggle,
-    .evdev_identify = evdev_is_adb,
+    /* .evdev_identify = evdev_is_adb, */
   },
 
   {  /* PowerBook3,5 */
@@ -100,7 +100,7 @@ struct machine_ops pb_mops[] = {
     .lcd_backlight_probe = r9x00_sysfs_backlight_probe,
     .lcd_backlight_step = sysfs_backlight_step,
     .lcd_backlight_toggle = sysfs_backlight_toggle,
-    .evdev_identify = evdev_is_adb,
+    /* .evdev_identify = evdev_is_adb, */
   },
 
   /* PowerBook4,* -> G3 iBooks */
@@ -110,7 +110,7 @@ struct machine_ops pb_mops[] = {
     .lcd_backlight_probe = nvidia_sysfs_backlight_probe,
     .lcd_backlight_step = sysfs_backlight_step,
     .lcd_backlight_toggle = sysfs_backlight_toggle,
-    .evdev_identify = evdev_is_adb,
+    /* .evdev_identify = evdev_is_adb, */
   },
 
   {  /* PowerBook5,2 */
@@ -118,7 +118,7 @@ struct machine_ops pb_mops[] = {
     .lcd_backlight_probe = r9x00_sysfs_backlight_probe,
     .lcd_backlight_step = sysfs_backlight_step,
     .lcd_backlight_toggle = sysfs_backlight_toggle,
-    .evdev_identify = evdev_is_adb,
+    /* .evdev_identify = evdev_is_adb, */
   },
 
   {  /* PowerBook5,3 */
@@ -126,7 +126,7 @@ struct machine_ops pb_mops[] = {
     .lcd_backlight_probe = r9x00_sysfs_backlight_probe,
     .lcd_backlight_step = sysfs_backlight_step,
     .lcd_backlight_toggle = sysfs_backlight_toggle,
-    .evdev_identify = evdev_is_adb,
+    /* .evdev_identify = evdev_is_adb, */
   },
 
   {  /* PowerBook5,4 */
@@ -134,7 +134,7 @@ struct machine_ops pb_mops[] = {
     .lcd_backlight_probe = r9x00_sysfs_backlight_probe,
     .lcd_backlight_step = sysfs_backlight_step,
     .lcd_backlight_toggle = sysfs_backlight_toggle,
-    .evdev_identify = evdev_is_adb,
+    /* .evdev_identify = evdev_is_adb, */
   },
 
   {  /* PowerBook5,5 */
@@ -142,7 +142,7 @@ struct machine_ops pb_mops[] = {
     .lcd_backlight_probe = r9x00_sysfs_backlight_probe,
     .lcd_backlight_step = sysfs_backlight_step,
     .lcd_backlight_toggle = sysfs_backlight_toggle,
-    .evdev_identify = evdev_is_adb,
+    /* .evdev_identify = evdev_is_adb, */
   },
 
   {  /* PowerBook5,6 */
@@ -150,7 +150,7 @@ struct machine_ops pb_mops[] = {
     .lcd_backlight_probe = r9x00_sysfs_backlight_probe,
     .lcd_backlight_step = sysfs_backlight_step,
     .lcd_backlight_toggle = sysfs_backlight_toggle,
-    .evdev_identify = evdev_is_fountain,
+    /* .evdev_identify = evdev_is_fountain, */
   },
 
   {  /* PowerBook5,7 */
@@ -158,7 +158,7 @@ struct machine_ops pb_mops[] = {
     .lcd_backlight_probe = r9x00_sysfs_backlight_probe,
     .lcd_backlight_step = sysfs_backlight_step,
     .lcd_backlight_toggle = sysfs_backlight_toggle,
-    .evdev_identify = evdev_is_fountain,
+    /* .evdev_identify = evdev_is_fountain, */
   },
 
   {  /* PowerBook5,8 */
@@ -166,7 +166,7 @@ struct machine_ops pb_mops[] = {
     .lcd_backlight_probe = r9x00_sysfs_backlight_probe,
     .lcd_backlight_step = sysfs_backlight_step,
     .lcd_backlight_toggle = sysfs_backlight_toggle,
-    .evdev_identify = evdev_is_geyser,
+    /* .evdev_identify = evdev_is_geyser, */
   },
 
   {  /* PowerBook5,9 */
@@ -174,7 +174,7 @@ struct machine_ops pb_mops[] = {
     .lcd_backlight_probe = r9x00_sysfs_backlight_probe,
     .lcd_backlight_step = sysfs_backlight_step,
     .lcd_backlight_toggle = sysfs_backlight_toggle,
-    .evdev_identify = evdev_is_geyser,
+    /* .evdev_identify = evdev_is_geyser, */
   },
 
   /* G4 iBooks & 12" PowerBooks */
@@ -184,7 +184,7 @@ struct machine_ops pb_mops[] = {
     .lcd_backlight_probe = nvidia_sysfs_backlight_probe,
     .lcd_backlight_step = sysfs_backlight_step,
     .lcd_backlight_toggle = sysfs_backlight_toggle,
-    .evdev_identify = evdev_is_adb,
+    /* .evdev_identify = evdev_is_adb, */
   },
 
   {  /* PowerBook6,2 */
@@ -192,7 +192,7 @@ struct machine_ops pb_mops[] = {
     .lcd_backlight_probe = nvidia_sysfs_backlight_probe,
     .lcd_backlight_step = sysfs_backlight_step,
     .lcd_backlight_toggle = sysfs_backlight_toggle,
-    .evdev_identify = evdev_is_adb,
+    /* .evdev_identify = evdev_is_adb, */
   },
 
   {  /* PowerBook6,3 */
@@ -200,7 +200,7 @@ struct machine_ops pb_mops[] = {
     .lcd_backlight_probe = r9x00_sysfs_backlight_probe,
     .lcd_backlight_step = sysfs_backlight_step,
     .lcd_backlight_toggle = sysfs_backlight_toggle,
-    .evdev_identify = evdev_is_adb,
+    /* .evdev_identify = evdev_is_adb, */
   },
 
   {  /* PowerBook6,4 */
@@ -208,7 +208,7 @@ struct machine_ops pb_mops[] = {
     .lcd_backlight_probe = nvidia_sysfs_backlight_probe,
     .lcd_backlight_step = sysfs_backlight_step,
     .lcd_backlight_toggle = sysfs_backlight_toggle,
-    .evdev_identify = evdev_is_adb,
+    /* .evdev_identify = evdev_is_adb, */
   },
 
   {  /* PowerBook6,5 */
@@ -216,7 +216,7 @@ struct machine_ops pb_mops[] = {
     .lcd_backlight_probe = r9x00_sysfs_backlight_probe,
     .lcd_backlight_step = sysfs_backlight_step,
     .lcd_backlight_toggle = sysfs_backlight_toggle,
-    .evdev_identify = evdev_is_adb,
+    /* .evdev_identify = evdev_is_adb, */
   },
 
   /* Looks like PowerBook6,6 never made it to the market ? */
@@ -226,7 +226,7 @@ struct machine_ops pb_mops[] = {
     .lcd_backlight_probe = r9x00_sysfs_backlight_probe,
     .lcd_backlight_step = sysfs_backlight_step,
     .lcd_backlight_toggle = sysfs_backlight_toggle,
-    .evdev_identify = evdev_is_adb,
+    /* .evdev_identify = evdev_is_adb, */
   },
 
   {  /* PowerBook6,8 */
@@ -234,7 +234,7 @@ struct machine_ops pb_mops[] = {
     .lcd_backlight_probe = nvidia_sysfs_backlight_probe,
     .lcd_backlight_step = sysfs_backlight_step,
     .lcd_backlight_toggle = sysfs_backlight_toggle,
-    .evdev_identify = evdev_is_adb,
+    /* .evdev_identify = evdev_is_adb, */
   }
 };
 
@@ -248,7 +248,7 @@ struct machine_ops mb_mops[] = {
     .lcd_backlight_probe = x1600_backlight_probe,
     .lcd_backlight_step = x1600_backlight_step,
     .lcd_backlight_toggle = x1600_backlight_toggle,
-    .evdev_identify = evdev_is_geyser3,
+    /* .evdev_identify = evdev_is_geyser3, */
   },
 
   {  /* MacBookPro2,1 / MacBookPro2,2 (Core2 Duo) */
@@ -256,7 +256,7 @@ struct machine_ops mb_mops[] = {
     .lcd_backlight_probe = x1600_backlight_probe,
     .lcd_backlight_step = x1600_backlight_step,
     .lcd_backlight_toggle = x1600_backlight_toggle,
-    .evdev_identify = evdev_is_geyser4,
+    /* .evdev_identify = evdev_is_geyser4, */
   },
 
   {  /* MacBookPro3,1 (15" & 17", Core2 Duo, June 2007) */
@@ -264,7 +264,15 @@ struct machine_ops mb_mops[] = {
     .lcd_backlight_probe = nv8600mgt_backlight_probe,
     .lcd_backlight_step = nv8600mgt_backlight_step,
     .lcd_backlight_toggle = nv8600mgt_backlight_toggle,
-    .evdev_identify = evdev_is_geyser4,
+    /* .evdev_identify = evdev_is_geyser4, */
+  },
+
+  {  /* MacBookPro4,1 (15" & 17", Core2 Duo, February 2008) */
+    .type = MACHINE_MACBOOKPRO_4,
+    .lcd_backlight_probe = nv8600mgt_backlight_probe,
+    .lcd_backlight_step = nv8600mgt_backlight_step,
+    .lcd_backlight_toggle = nv8600mgt_backlight_toggle,
+    /* .evdev_identify = evdev_is_wellspring2, */
   },
 
   /* MacBook machines */
@@ -274,7 +282,7 @@ struct machine_ops mb_mops[] = {
     .lcd_backlight_probe = gma950_backlight_probe,
     .lcd_backlight_step = gma950_backlight_step,
     .lcd_backlight_toggle = gma950_backlight_toggle,
-    .evdev_identify = evdev_is_geyser3,
+    /* .evdev_identify = evdev_is_geyser3, */
   },
 
   {  /* MacBook2,1 (Core2 Duo) */
@@ -282,7 +290,7 @@ struct machine_ops mb_mops[] = {
     .lcd_backlight_probe = gma950_backlight_probe,
     .lcd_backlight_step = gma950_backlight_step,
     .lcd_backlight_toggle = gma950_backlight_toggle,
-    .evdev_identify = evdev_is_geyser4,
+    /* .evdev_identify = evdev_is_geyser4, */
   },
 
   {  /* MacBook3,1 (Core2 Duo Santa Rosa, November 2007) */
@@ -290,16 +298,25 @@ struct machine_ops mb_mops[] = {
     .lcd_backlight_probe = gma950_backlight_probe, /* gma950 supports the gma965 */
     .lcd_backlight_step = gma950_backlight_step,
     .lcd_backlight_toggle = gma950_backlight_toggle,
-    .evdev_identify = evdev_is_geyser4hf,
+    /* .evdev_identify = evdev_is_geyser4hf, */
+  },
+
+  {  /* MacBook4,1 (Core2 Duo, February 2008) */
+    .type = MACHINE_MACBOOK_4,
+    .lcd_backlight_probe = gma950_backlight_probe, /* gma950 supports the gma965 */
+    .lcd_backlight_step = gma950_backlight_step,
+    .lcd_backlight_toggle = gma950_backlight_toggle,
+    /* .evdev_identify = evdev_is_geyser4hf, */
   },
 
   /* MacBook Air machines */
-  {  /* MacBook Air1,1 (January 2008) */
+
+  {  /* MacBookAir1,1 (January 2008) */
     .type = MACHINE_MACBOOKAIR_1,
     .lcd_backlight_probe = gma950_backlight_probe, /* gma950 supports the gma965 */
     .lcd_backlight_step = gma950_backlight_step,
     .lcd_backlight_toggle = gma950_backlight_toggle,
-    .evdev_identify = evdev_is_geyser4hf,
+    /* .evdev_identify = evdev_is_wellspring, */
   }
 };
 #endif /* __powerpc__ */
@@ -368,6 +385,7 @@ logdebug(char *fmt, ...)
 void
 kbd_set_fnmode(void)
 {
+  int errno1;
   FILE *fp;
 
   if ((general_cfg.fnmode < 1) || (general_cfg.fnmode > 2))
@@ -376,10 +394,12 @@ kbd_set_fnmode(void)
   fp = fopen(KBD_FNMODE_FILE, "a");
   if (fp == NULL)
     {
+      errno1 = errno;
+
       fp = fopen(KBD_FNMODE_FILE2620, "a");
       if (fp == NULL)
         {
-          logmsg(LOG_INFO, "Could not open %s", KBD_FNMODE_FILE);
+          logmsg(LOG_INFO, "Could not open %s: %s", KBD_FNMODE_FILE, strerror(errno1));
           logmsg(LOG_INFO, "Could not open %s: %s", KBD_FNMODE_FILE2620, strerror(errno));
           return;
         }
@@ -578,6 +598,9 @@ check_machine_smbios(void)
   /* Core2 Duo MacBook Pro 15" & 17" (June 2007) */
   else if (strcmp(prop, "MacBookPro3,1") == 0)
     ret = MACHINE_MACBOOKPRO_3;
+  /* Core2 Duo MacBook Pro 15" & 17" (February 2008) */
+  else if (strcmp(prop, "MacBookPro4,1") == 0)
+    ret = MACHINE_MACBOOKPRO_4;
   /* Core Duo MacBook (May 2006) */
   else if (strcmp(prop, "MacBook1,1") == 0)
     ret = MACHINE_MACBOOK_1;
@@ -587,8 +610,11 @@ check_machine_smbios(void)
   /* Core2 Duo Santa Rosa MacBook (November 2007) */
   else if (strcmp(prop, "MacBook3,1") == 0)
     ret = MACHINE_MACBOOK_3;
+  /* Core2 Duo MacBook (February 2008) */
+  else if (strcmp(prop, "MacBook4,1") == 0)
+    ret = MACHINE_MACBOOK_4;
   /* MacBook Air (January 2008) */
-  else if (strcmp(prop, "MacBook Air1,1") == 0)
+  else if (strcmp(prop, "MacBookAir1,1") == 0)
     ret = MACHINE_MACBOOKAIR_1;
   else
     logmsg(LOG_ERR, "Unknown Apple machine: %s", prop);
@@ -606,7 +632,7 @@ check_machine_smbios(void)
 static void
 usage(void)
 {
-  printf("pommed v" M_VERSION " ($Rev: 434 $) Apple laptops hotkeys handler\n");
+  printf("pommed v" M_VERSION " ($Rev: 460 $) Apple laptops hotkeys handler\n");
   printf("Copyright (C) 2006-2008 Julien BLACHE <jb@jblache.org>\n");
 
   printf("Usage:\n");
@@ -651,7 +677,7 @@ main (int argc, char **argv)
 	    break;
 
 	  case 'v':
-	    printf("pommed v" M_VERSION " ($Rev: 434 $) Apple laptops hotkeys handler\n");
+	    printf("pommed v" M_VERSION " ($Rev: 460 $) Apple laptops hotkeys handler\n");
 	    printf("Copyright (C) 2006-2008 Julien BLACHE <jb@jblache.org>\n");
 
 	    exit(0);
@@ -670,7 +696,7 @@ main (int argc, char **argv)
       openlog("pommed", LOG_PID, LOG_DAEMON);
     }
 
-  logmsg(LOG_INFO, "pommed v" M_VERSION " ($Rev: 434 $) Apple laptops hotkeys handler");
+  logmsg(LOG_INFO, "pommed v" M_VERSION " ($Rev: 460 $) Apple laptops hotkeys handler");
   logmsg(LOG_INFO, "Copyright (C) 2006-2008 Julien BLACHE <jb@jblache.org>");
 
   /* Load our configuration */
