@@ -1,12 +1,12 @@
 /*
- * $Id: pommed.h 437 2008-02-09 08:05:44Z jblache $
+ * $Id: pommed.h 464 2008-05-18 10:05:43Z jblache $
  */
 
 #ifndef __POMMED_H__
 #define __POMMED_H__
 
 
-#define M_VERSION "1.15"
+#define M_VERSION "1.18"
 
 
 extern int debug;
@@ -33,10 +33,12 @@ typedef enum
     MACHINE_MACBOOKPRO_1,
     MACHINE_MACBOOKPRO_2,
     MACHINE_MACBOOKPRO_3,
+    MACHINE_MACBOOKPRO_4,
 
     MACHINE_MACBOOK_1,
     MACHINE_MACBOOK_2,
     MACHINE_MACBOOK_3,
+    MACHINE_MACBOOK_4,
 
     MACHINE_MACBOOKAIR_1,
 #else
@@ -72,7 +74,6 @@ struct machine_ops
   int (*lcd_backlight_probe) (void);
   void (*lcd_backlight_step) (int dir);
   void (*lcd_backlight_toggle) (int lvl);
-  int (*evdev_identify) (unsigned short *id);
 };
 
 extern struct machine_ops *mops;
